@@ -24,7 +24,7 @@ BEGIN {
    $prog_name    =~ s{^.*[\\/]}{}g;
 }
 
-our $VERSION = '1.413'; $VERSION = eval $VERSION;
+our $VERSION = '1.414'; $VERSION = eval $VERSION;
 
 our $tmp_dir = undef;
 
@@ -45,8 +45,8 @@ sub _usage { _croak "MCE::Signal error: $_[0] is not a valid option"; }
 sub _flag  { 1; }
 
 my $_keep_tmp_dir = 0;
-my $_no_kill9     = 0;
 my $_no_sigmsg    = 0;
+my $_no_kill9     = 0;
 my $_loaded;
 
 sub import {
@@ -62,14 +62,15 @@ sub import {
    while (my $_arg = shift) {
 
       $_keep_tmp_dir = _flag() and next if ($_arg eq '-keep_tmp_dir');
-      $_no_kill9     = _flag() and next if ($_arg eq '-no_kill9');
       $_no_sigmsg    = _flag() and next if ($_arg eq '-no_sigmsg');
+      $_no_kill9     = _flag() and next if ($_arg eq '-no_kill9');
+
       $_no_setpgrp   = _flag() and next if ($_arg eq '-no_setpgrp');
       $_setpgrp      = _flag() and next if ($_arg eq '-setpgrp');
+
       $_use_dev_shm  = _flag() and next if ($_arg eq '-use_dev_shm');
 
       _usage($_arg) if ($_arg =~ /^-/);
-
       push @_export_args, $_arg;
    }
 
@@ -440,12 +441,15 @@ MCE::Signal - Provides tmp_dir creation & signal handling for Many-Core Engine.
 
 =head1 VERSION
 
-This document describes MCE::Signal version 1.413
+This document describes MCE::Signal version 1.414
 
 =head1 SYNOPSIS
 
  use MCE::Signal qw( [-keep_tmp_dir] [-use_dev_shm] );
 
+ use MCE;   ## MCE loads MCE::Signal when not present.
+            ## Include MCE::Signal first for options to take effect.
+
 =head1 DESCRIPTION
 
 This package configures $SIG{HUP,INT,PIPE,QUIT,TERM,XCPU,XFSZ} to point to
@@ -457,11 +461,11 @@ and terminates itself.
 The location of temp dir resides under $ENV{TEMP} if defined, otherwise
 /dev/shm if writeable and -use_dev_shm is specified, or /tmp.
 
-The temp dir resides under $ENV{TEMP}/mce/ when running Perl on Microsoft
+The temp dir resides under $ENV{TEMP}/mce/ for native Perl on Microsoft
 Windows.
 
-As of MCE 1.405, MCE::Signal no longer calls setpgrp by default. If needed,
-just pass the -setpgrp option to MCE::Signal.
+As of MCE 1.405, MCE::Signal no longer calls setpgrp by default. Pass the
+-setpgrp option to MCE::Signal to call setpgrp.
 
  ## Running MCE through Daemon::Control requires setpgrp to be called.
 
@@ -475,8 +479,8 @@ The following are available arguments and their meanings.
 
  -use_dev_shm      - Create the temporary directory under /dev/shm
 
- -no_kill9         - Do not kill -9 after receiving a signal to terminate
  -no_sigmsg        - Do not display a message when receiving a signal
+ -no_kill9         - Do not kill -9 after receiving a signal to terminate
 
  -setpgrp          - Calls setpgrp to set the process group for the process
 
